// transmitter.pde
//
// Simple example of how to use VirtualWire to transmit messages
// Implements a simplex (one-way) transmitter with an TX-C1 module
//
// See VirtualWire.h for detailed API docs
// Author: Mike McCauley (mikem@open.com.au)
// Copyright (C) 2008 Mike McCauley
// $Id: transmitter.pde,v 1.3 2009/03/30 00:07:24 mikem Exp $

#include <VirtualWire.h>

bool lastReed;  //create a boolean variable to tell us the last state of the switch

void setup()
{
    Serial.begin(9600);	  // Debugging only
    Serial.println("setup");

    // Initialise the IO and ISR
    vw_set_ptt_inverted(true); // Required for DR3100
    vw_setup(2000);	 // Bits per sec
    
    pinMode(6, INPUT);  //set the reed switch as an input
    lastReed = digitalRead(6);  //set the inital status of the reed switch
}

void loop()
{
    const char *msg = "door opened";
    if(digitalRead(6) == false && lastReed == true){  //send the message if the door is open, and it was last read as closed
      digitalWrite(13, true); // Flash a light to show transmitting
      vw_send((uint8_t *)msg, strlen(msg));
      vw_wait_tx(); // Wait until the whole message is gone
      digitalWrite(13, false);
      delay(200);
    }
    lastReed = digitalRead(6);  //this will keep us from always sending a message
}
